#ifdef GL_ES
precision mediump float;
#endif

uniform sampler2D CC_Texture0;
uniform float factor;
uniform float offset;
uniform float width;
uniform vec4 color;

varying vec4 v_fragmentColor;
varying vec2 v_texCoord;

void main()
{
    vec4 texColor = texture2D(CC_Texture0, v_texCoord);
    // line (x+y-offset=0) offset:[0, 2] (2->0)
    //     |y
    //     |
    // ____|0__ 1__2____x
    //     |       |
    //     |_______|*
    float distance = abs(v_texCoord[0]+v_texCoord[1]-offset)/1.414;
    // linear gradient
    // (1/width)x + y = 1
    distance = 1.0-(1.0/width)*distance;
    distance = max(distance, 0.0);
    vec4 sam = vec4(0.0,0.0,0.0,0.0);
    sam[0] = color[0] * distance;
    sam[1] = color[1] * distance;
    sam[2] = color[2] * distance;
    sam[3] = distance;
    
    // blend additive
    float alpha = sam[3]*texColor[3];
    texColor[0] = texColor[0] + sam[0]*alpha*factor;
    texColor[1] = texColor[1] + sam[1]*alpha*factor;
    texColor[2] = texColor[2] + sam[2]*alpha*factor;
    gl_FragColor = v_fragmentColor * texColor;
}
